[![](https://img.shields.io/github/release/mueslo/fplore.svg?style=flat-square)](https://github.com/mueslo/fplore/releases)
[![](https://img.shields.io/pypi/v/fplore.svg?style=flat-square)](https://pypi.org/project/fplore/)
[![](https://img.shields.io/travis/mueslo/fplore.svg?style=flat-square)](https://travis-ci.org/mueslo/fplore)
[![](https://img.shields.io/readthedocs/fplore.svg?style=flat-square)](https://fplore.readthedocs.io)
[![](https://img.shields.io/github/license/mueslo/fplore.svg?style=flat-square)](https://github.com/mueslo/fplore/blob/master/LICENSE)


# fplore
A python library for [FPLO](https://www.fplo.de/) run evaluation.

:construction: Still a work in progress, syntax may change without notice. :construction:

:raising_hand: If you have completed FPLO runs, It'd be super helpful if you could send them to me so I can test various cases and implement new features. Thanks! Either drop me an e-mail or submit a pull request [here](https://github.com/mueslo/fplore_example_data/).

## Installation

The recommended way to install `fplore` is via the packages made available at PyPI by using the tool `pip`:
 ``pip install fplore``.
 
Ideally, you should never install packages from PyPI as system packages, rather you should use [virtual environments](https://realpython.com/python-virtual-environments-a-primer/). If for some reason `virtualenv` is unavailable to you, installing for your user only (`pip install --user`) is preferable to forced system-wide installation.

## Gallery
[
![Brillouin zone](https://fplore.readthedocs.io/en/latest/_images/sphx_glr_brillouin_zone_thumb.png)
![Band plot](https://fplore.readthedocs.io/en/latest/_images/sphx_glr_band_plot_thumb.png)
![Band projection](https://fplore.readthedocs.io/en/latest/_images/sphx_glr_project_thumb.png)
![Fermi surface projection](https://fplore.readthedocs.io/en/latest/_images/sphx_glr_proj_fermisurf_thumb.png)
](https://fplore.readthedocs.io/en/latest/gallery/)

## Usage

See the documentation at [fplore.readthedocs.io](https://fplore.readthedocs.io/en/latest).


